@@ -75,7 +75,6 @@ typedef enum {
 static gint
 sort_doc_by_filename(gconstpointer a,gconstpointer b)
 {
-	gint retval=0;
 	if (!a || !b)
 		return 0;
 	return g_strcmp0(gtk_label_get_text(GTK_LABEL(DOCUMENT(a)->tab_label)) , gtk_label_get_text(GTK_LABEL(DOCUMENT(b)->tab_label)));
@@ -214,7 +213,7 @@ side_panel_cleanup(Tbfwin * bfwin)
 	if (main_v->sidepanel_destroygui) {
 		GSList *tmplist = main_v->sidepanel_destroygui;
 		while (tmplist) {
-			void *(*func) () = tmplist->data;
+			void *(*func) (Tbfwin *) = tmplist->data;
 			DEBUG_MSG("side_panel_cleanup, calling plugin sidepanel_destroygui func %p on bfwin %p\n", tmplist->data, bfwin);
 			func(bfwin);
 			tmplist = g_slist_next(tmplist);
@@ -304,7 +303,7 @@ side_panel_build(Tbfwin * bfwin)
 	if (main_v->sidepanel_initgui) {
 		GSList *tmplist = main_v->sidepanel_initgui;
 		while (tmplist) {
-			void *(*func) () = tmplist->data;
+			void *(*func) (Tbfwin *) = tmplist->data;
 			DEBUG_MSG("side_panel_build, calling plugin sidepanel_initgui func %p\n", tmplist->data);
 			func(bfwin);
 			tmplist = g_slist_next(tmplist);
@@ -1300,7 +1299,7 @@ bfwin_current_document_changed_notify(Tbfwin *bfwin, Tdocument *olddoc, Tdocumen
 
 void
 bfwin_current_document_change_register(Tbfwin *bfwin, CurdocChangedCallback func, gpointer data) {
-	callback_register(&bfwin->curdoc_changed, func, data);
+	callback_register(&bfwin->curdoc_changed, (void (*)())func, data);
 }
 
 void
@@ -1315,7 +1314,7 @@ bfwin_current_document_change_remove_all(Tbfwin *bfwin) {
 
 void
 bfwin_document_insert_text_register(Tbfwin *bfwin, DocInsertTextCallback func, gpointer data) {
-	callback_register(&bfwin->doc_insert_text, func, data);
+	callback_register(&bfwin->doc_insert_text, (void (*)())func, data);
 }
 
 void
@@ -1325,7 +1324,7 @@ bfwin_document_insert_text_remove_by_data(Tbfwin *bfwin, gpointer data) {
 
 void
 bfwin_document_delete_range_register(Tbfwin *bfwin, DocDeleteRangeCallback func, gpointer data) {
-	callback_register(&bfwin->doc_delete_range, func, data);
+	callback_register(&bfwin->doc_delete_range, (void (*)())func, data);
 }
 
 void
@@ -1336,7 +1335,7 @@ bfwin_document_delete_range_remove_by_data(Tbfwin *bfwin, gpointer data) {
 void
 bfwin_document_destroy_register(Tbfwin *bfwin, DocDestroyCallback func, gpointer data)
 {
-	callback_register(&bfwin->doc_destroy, func, data);
+	callback_register(&bfwin->doc_destroy, (void (*)())func, data);
 }
 void
 bfwin_document_destroy_remove_by_data(Tbfwin *bfwin, gpointer data)
@@ -2003,3 +2002,19 @@ bfwin_switch_to_document_by_pointer(Tbfwin * bfwin, Tdocument * document)
 		return FALSE;
 	return bfwin_switch_to_document_by_index(bfwin, i);
 }
+
+/** 
+ * doc_still_exists
+ *
+ * test if a Tdocument pointer still points to a document in this window
+ *
+ *
+ */
+gboolean
+bfwin_has_document_by_pointer(Tbfwin * bfwin, Tdocument * document)
+{
+	if (g_list_index(bfwin->documentlist, document)==-1)
+		return FALSE;
+	return TRUE;
+}
+
