@@ -3,6 +3,7 @@
  * bfwin_uimanager.c
  *
  * Copyright (C) 2011, 2015, 2017 James Hayward and Olivier Sessink
+ * Copyright (C) 2017 - 2025 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,6 +47,7 @@
 #include "snr3.h"
 #include "undo_redo.h"
 #include "print.h"
+#include "gtk_easy.h"
 
 #define MAIN_MENU_UI PKGDATADIR"/ui/bluefish_menu_ui.xml"
 #define MAIN_TOOLBAR_UI PKGDATADIR"/ui/bluefish_toolbar_ui.xml"
@@ -668,13 +670,13 @@ ui_project_save_as(GtkAction * action, gpointer user_data)
 static void
 ui_indenting_to_spaces(GtkAction * action, gpointer user_data)
 {
-	convert_identing(BFWIN(user_data)->current_document, FALSE);
+	convert_indenting(BFWIN(user_data)->current_document, FALSE);
 }
 
 static void
 ui_indenting_to_tabs(GtkAction * action, gpointer user_data)
 {
-	convert_identing(BFWIN(user_data)->current_document, TRUE);
+	convert_indenting(BFWIN(user_data)->current_document, TRUE);
 }
 
 static void
@@ -1171,7 +1173,7 @@ lang_mode_menu_activate(GtkAction * action, gpointer user_data)
 			tmpbflang = langmgr_get_bflang(oldmime, NULL);
 
 			DEBUG_MSG("lang_mode_menu_activate, got %p for tmpbflang with name %s\n", tmpbflang,
-					  tmpbflang->name);
+					  tmpbflang?tmpbflang->name:"Undefined");
 
 			if (!tmpbflang && g_strcmp0(oldmime, "application/octet-stream") != 0) {
 				/* ask the user to register oldmime for the chosen language */
@@ -1349,6 +1351,14 @@ bfwin_main_ui_init(Tbfwin * bfwin, GtkWidget * vbox)
 #endif
 
 	bfwin->menubar = gtk_ui_manager_get_widget(manager, "/MainMenu");
+#if GTK_CHECK_VERSION(3,0,0)
+#ifndef MAC_INTEGRATION
+	if (main_v->props.dynamic_menu_shortcut) {
+		gtk3_enable_dynamic_menu_shortcuts(bfwin->menubar, NULL);
+	}
+#endif
+#endif
+
 #if GTK_CHECK_VERSION(3,4,0)
 	gtk_container_add(GTK_CONTAINER(vbox), bfwin->menubar);
 #else
@@ -1598,6 +1608,17 @@ dynamic_menu_item_create(GtkUIManager * uimanager, GtkActionGroup * action_group
 	g_signal_connect(G_OBJECT(action), "activate", callback, callbackdata);
 	DEBUG_MSG("dynamic_menu_item_create, add action %s at path %s\n", action_name, path);
 	gtk_ui_manager_add_ui(uimanager, merge_id, path, action_name, action_name, GTK_UI_MANAGER_MENUITEM, TRUE);
+#if GTK_CHECK_VERSION(3,0,0)
+#ifndef MAC_INTEGRATION
+	if (main_v->props.dynamic_menu_shortcut) {
+		gchar *newpath = g_strconcat(path, "/", action_name, NULL);
+		GtkWidget *menuitem = gtk_ui_manager_get_widget(uimanager, newpath);
+		if (menuitem)
+			gtk3_enable_dynamic_menu_shortcuts_menuitem(menuitem, NULL);
+		g_free(newpath);
+	}
+#endif
+#endif
 	g_object_unref(action);
 }
 
@@ -1909,7 +1930,7 @@ bfwin_outputbox_menu_create(Tbfwin * bfwin)
 }
 
 static gchar *
-recent_menu_label(const gchar *curi, GFile *uri) 
+recent_menu_label(gchar *curi, GFile *uri) 
 {
 	gchar *label = curi;
 	if (uri && g_file_is_native(uri)) {
@@ -1946,7 +1967,7 @@ bfwin_recent_menu_remove(Tbfwin * bfwin, gboolean project, const gchar * curi, G
 	GList *tmplist;
 	gchar *label;
 	DEBUG_MSG("bfwin_recent_menu_remove curi=%s\n",curi);
-	label = recent_menu_label(curi, uri);
+	label = recent_menu_label((gchar *)curi, uri);
 	if (!project && bfwin->session != main_v->session) {
 		recent_menu_remove_backend(bfwin, "/MainMenu/FileMenu/FileOpenRecent", label);
 		return;
@@ -1970,11 +1991,19 @@ recent_menu_activate(GtkMenuItem * menuitem, gpointer user_data)
 	GFile *uri;
 	const gchar *str = gtk_menu_item_get_label(menuitem);
 	gint len = strlen(str);
+#ifdef WIN32
+	if (len > 3 && (str[0]=='/' || str[1]==':')) { /* C: D: etc. */
+		uri = g_file_new_for_path(str);
+	} else {
+		uri = g_file_new_for_uri(str);
+	}
+#else
 	if (str[0]=='/') {
 		uri = g_file_new_for_path(str);
 	} else {
 		uri = g_file_new_for_uri(str);
 	}
+#endif
 	if (g_strcmp0(str + len - 10, ".bfproject") == 0) {
 		gint status = project_open_from_file(bfwin, uri);
 		if (status == 0) {
@@ -2010,12 +2039,12 @@ recent_menu_add_backend(Tbfwin * bfwin, const gchar * menupath, const gchar * cu
 {
 	GtkWidget *menuitem, *menu;
 	GList *tmplist, *list;
-	gchar *label=curi;
+	gchar *label=(gchar *)curi;
 	gint num = 0;
 	menuitem = gtk_ui_manager_get_widget(bfwin->uimanager, menupath);
 	menu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(menuitem));
 	
-	label = recent_menu_label(curi, uri);
+	label = recent_menu_label((gchar *)curi, uri);
 
 	/* avoid duplicate entries,
 	   if recent_means_recently_closed==1 this is not essential, because
