@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * gtk_easy.c
  *
- * Copyright (C) 1999-2012 Olivier Sessink
+ * Copyright (C) 1999-2025 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -520,7 +520,7 @@ spinbut_output(GtkSpinButton *spin,gpointer data)
 	}
 	text = gtk_entry_get_text(GTK_ENTRY(spin));
 	testval = strtod(text, &endptr);
-	if (endptr == text) {
+	if (endptr == text && testval==0) {
 		/*g_print("spinbut_output, no conversion to float possible for '%s', adjustment has value %d, return TRUE\n", text, (int)gtk_adjustment_get_value(gtk_spin_button_get_adjustment(spin)));*/
 		return TRUE;
 	}
@@ -1570,20 +1570,6 @@ boxed_accelerator_button(const gchar * labeltext, const gchar * accel, GtkWidget
 	return returnwidget;
 }
 
-gchar *
-gdk_color_to_hexstring(GdkColor * color, gboolean websafe)
-{
-	gchar *tmpstr;
-	tmpstr = g_malloc(8 * sizeof(char));
-	if (websafe) {
-		g_snprintf(tmpstr, 8, "#%.2X%.2X%.2X", (0x33 * color->red / (256 * 0x33)),
-				   (0x33 * color->green / (256 * 0x33)), (0x33 * color->blue / (256 * 0x33)));
-	} else {
-		g_snprintf(tmpstr, 8, "#%.2X%.2X%.2X", color->red / 256, color->green / 256, color->blue / 256);
-	}
-	return tmpstr;
-}
-
 static void
 color_entry_changed_lcb(GtkWidget * widget, gpointer data)
 {
@@ -1605,7 +1591,7 @@ color_set_lcb(GtkWidget * widget, gpointer data)
 	GdkColor gcolor;
 	gchar *string;
 	gtk_color_button_get_color(GTK_COLOR_BUTTON(widget), &gcolor);
-	string = gdk_color_to_hexstring(&gcolor, FALSE);
+	string = gdk_color_to_hexstring(&gcolor);
 	gtk_entry_set_text(GTK_ENTRY(data), string);
 	g_free(string);
 }
@@ -1622,3 +1608,89 @@ color_but_new2(GtkWidget * entry)
 	return cbut;
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
+#ifndef MAC_INTEGRATION
+/* ********************************************************************
+ * following code implements dynamic menu shortcut setting that was
+ * possible in gtk2 but was removed in gtk3 
+********************************************************************** */
+
+static GtkWidget *hovered_item = NULL;
+
+/* Hover tracking */
+static gboolean on_item_enter(GtkWidget *item, GdkEventCrossing *e, gpointer d) {
+	hovered_item = item;
+	return FALSE;
+}
+
+static gboolean on_item_leave(GtkWidget *item, GdkEventCrossing *e, gpointer d) {
+	if (hovered_item == item) hovered_item = NULL;
+	return FALSE;
+}
+
+/* Key pressed while hovering over menu item */
+static gboolean on_menu_key_press(GtkWidget *menu, GdkEventKey *event, gpointer data) {
+	if (!hovered_item || !GTK_IS_MENU_ITEM(hovered_item)) 
+		return FALSE;
+	
+	gchar *accel_path = NULL;
+	g_object_get(G_OBJECT(hovered_item), "accel-path", &accel_path, NULL);
+	if (!accel_path || !*accel_path) {
+		g_free(accel_path);
+		return FALSE;
+	}
+	g_print("on_menu_key_press, change shortcut for accel_path=%s\n",accel_path);
+	guint accel_key = event->keyval;
+	GdkModifierType accel_mods = event->state & gtk_accelerator_get_default_mod_mask();
+	
+	/* Update GtkAccelMap */
+	gtk_accel_map_change_entry(accel_path, 0, 0, TRUE);
+	gtk_accel_map_change_entry(accel_path, accel_key, accel_mods, TRUE);
+	
+	/* Rebind the action so it is immediately active */
+	GtkAction *action = gtk_activatable_get_related_action(GTK_ACTIVATABLE(hovered_item));
+	if (action)
+		gtk_action_set_accel_path(action, accel_path);
+	
+	/*gchar *label = gtk_accelerator_get_label(accel_key, accel_mods);
+	g_print("Nieuwe shortcut voor %s → %s\n", accel_path, label);
+	g_free(label);*/
+	g_free(accel_path);
+	return TRUE;
+}
+
+/* Connect hover/key handlers recursively */
+void 
+gtk3_enable_dynamic_menu_shortcuts_menuitem(GtkWidget *menuitem, gpointer data) {
+
+	GType type = G_OBJECT_TYPE(menuitem);
+	const char *type_name = g_type_name(type);
+	g_print ("menuitem_connect_signals, item %p has type %s\n", menuitem, type_name);
+	
+	if (!GTK_IS_MENU_ITEM(menuitem)) {
+		g_print("menuitem_connect_signals, geen menu_item, return\n"); 
+		return;
+	}
+	gchar *accel_path = NULL;
+	g_object_get(G_OBJECT(menuitem), "accel-path", &accel_path, NULL);
+	if (accel_path) {
+		g_print("menuitem_connect_signals, accel_path=%s\n",accel_path);
+		g_free(accel_path);
+	}
+	
+	g_signal_connect(menuitem, "enter-notify-event", G_CALLBACK(on_item_enter), NULL);
+	g_signal_connect(menuitem, "leave-notify-event", G_CALLBACK(on_item_leave), NULL);
+	
+	GtkWidget *submenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(menuitem));
+	if (submenu && GTK_IS_MENU(submenu)) {
+		g_signal_connect(submenu, "key-press-event", G_CALLBACK(on_menu_key_press), NULL);
+		gtk_container_foreach(GTK_CONTAINER(submenu), gtk3_enable_dynamic_menu_shortcuts_menuitem, data);
+	}
+}
+
+
+void gtk3_enable_dynamic_menu_shortcuts(GtkWidget *menubar, gpointer data) {
+	gtk_container_foreach(GTK_CONTAINER(menubar), gtk3_enable_dynamic_menu_shortcuts_menuitem, data);
+}
+#endif /* MAC_INTEGRATION */
+#endif /* GTK_CHECK_VERSION(3,0,0) */
