@@ -21,6 +21,11 @@
 #define __RPOPUP_H_
 
 void rpopup_bevent_in_html_code(Tdocument *doc);
+
+void
+htmlbar_doc_view_button_press(GtkWidget * widget, GdkEventButton * bevent, Tdocument * doc,
+												GtkTextIter *so, GtkTextIter *eo,
+												gboolean is_color, gchar *pattern);
 gboolean rpopup_doc_located_tag(Tdocument *doc);
 gboolean rpopup_doc_located_color(Tdocument *doc);
 void rpopup_edit_tag_cb(GtkMenuItem *menuitem,Tdocument *doc);
